cd `dirname $0`
mkdir -p ../flatboat-build-linux
cd ../flatboat-build-linux
qmake CONFIG+=unix-local-debug ../flatboat/flatboat.pro
make
